==> virtdata-docs-2.11.28-sources.jar: io/virtdata/docsys/metafs/fs/renderfs/renderers/MarkdownProcessor.java <==
package io.virtdata.docsys.metafs.fs.renderfs.renderers;

import com.vladsch.flexmark.html.HtmlRenderer;
import com.vladsch.flexmark.parser.Parser;
import com.vladsch.flexmark.util.ast.Document;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.ExceptionContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.RenderedContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.StringContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.Renderer;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.RenderingScope;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.TemplateCompiler;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.TemplateView;

public class MarkdownProcessor implements TemplateCompiler {

    @Override
    public Renderer apply(TemplateView templateView) {
        return new MarkdownRenderer(templateView.get());
    }

    public static class MarkdownRenderer implements Renderer {
        protected final static Parser parser = Parser.builder().build();
        protected final static HtmlRenderer renderer = HtmlRenderer.builder().build();

        private final Document document;
        private long version;

        public MarkdownRenderer(String template) {
            document = parser.parse(template);
        }

        @Override
        public RenderedContent apply(RenderingScope targetPathView) {
            try {
                String rendered = renderer.render(document);
                this.version = targetPathView.getVersion();
                return new StringContent(rendered, targetPathView.getVersion());
            } catch (Exception e) {
                return new ExceptionContent(e, targetPathView.getVersion());
            }
        }

        @Override
        public long getVersion() {
            return this.version;
        }
    }

    @Override
    public String toString() {
        return "\uD83C\uDD6B";
//        return MarkdownProcessor.class.getSimpleName();
    }
}

==> virtdata-docs-2.11.29-sources.jar: io/virtdata/docsys/metafs/fs/renderfs/renderers/MarkdownProcessor.java <==
package io.virtdata.docsys.metafs.fs.renderfs.renderers;

import com.vladsch.flexmark.html.HtmlRenderer;
import com.vladsch.flexmark.parser.Parser;
import com.vladsch.flexmark.util.ast.Document;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.ExceptionContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.RenderedContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendered.StringContent;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.Renderer;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.RenderingScope;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.TemplateCompiler;
import io.virtdata.docsys.metafs.fs.renderfs.api.rendering.TemplateView;

public class MarkdownProcessor implements TemplateCompiler {

    @Override
    public Renderer apply(TemplateView templateView) {
        return new MarkdownRenderer(templateView.getRawTemplate());
    }

    public static class MarkdownRenderer implements Renderer {
        protected final static Parser parser = Parser.builder().build();
        protected final static HtmlRenderer renderer = HtmlRenderer.builder().build();

        private final Document document;
        private long version;

        public MarkdownRenderer(String template) {
            document = parser.parse(template);
        }

        @Override
        public RenderedContent apply(RenderingScope targetPathView) {
            try {
                String rendered = renderer.render(document);
                this.version = targetPathView.getVersion();
                return new StringContent(rendered, targetPathView.getVersion());
            } catch (Exception e) {
                return new ExceptionContent(e, targetPathView.getVersion());
            }
        }

        @Override
        public long getVersion() {
            return this.version;
        }

        @Override
        public String wrapError(String error) {
            return "\n```\nMarkdown Error:\n" + error + "\n```\n";
        }
    }

    @Override
    public String toString() {
        return "\uD83C\uDD6B";
//        return MarkdownProcessor.class.getSimpleName();
    }
}
